@@ -3,7 +3,7 @@ package MaxMind::DB::Reader;
 use strict;
 use warnings;
 
-our $VERSION = '1.000007';
+our $VERSION = '1.000008';
 
 use 5.010000;
 
@@ -41,7 +41,7 @@ MaxMind::DB::Reader - Read MaxMind DB files and look up IP addresses
 
 =head1 VERSION
 
-version 1.000007
+version 1.000008
 
 =head1 SYNOPSIS
 
@@ -178,7 +178,7 @@ Greg Oschwald <goschwald@maxmind.com>
 
 =item *
 
-Mateu X Hunter <hunter@missoula.org>
+Mateu X Hunter <mhunter@maxmind.com>
 
 =item *
 
